@@ -4,9 +4,9 @@ import tempfile
 import subprocess
 import sys
 
+from . import test_dir
 
-sequana_path = easydev.get_package_location('sequana_fastqc')
-sharedir = os.sep.join([sequana_path , "sequana_pipelines", 'fastqc', 'data'])
+sharedir = f"{test_dir}/data"
 
 
 # 
@@ -29,7 +29,6 @@ def test_standalone_script():
 def test_full():
 
     with tempfile.TemporaryDirectory() as directory:
-        print(directory)
         wk = directory
 
         cmd = "sequana_pipelines_fastqc --input-directory {} "
@@ -37,7 +36,10 @@ def test_full():
         cmd = cmd.format(sharedir, wk)
         subprocess.call(cmd.split())
 
-        stat = subprocess.call("sh fastqc.sh".split(), cwd=wk)
+
+        cmd = "snakemake -s fastqc.rules --wrapper-prefix https://raw.githubusercontent.com/sequana/sequana-wrappers/  -p --cores 2 "
+
+        stat = subprocess.call(cmd.split(), cwd=wk)
 
         assert os.path.exists(wk + "/summary.html")
         assert os.path.exists(wk + "/tree.html")
